@@ -197,6 +197,9 @@ def run(runner, job, docker):
                 config["variables"][name] = filevar.name
                 filevar.close()
             else:
+                # fix 'None' values
+                if var["value"] is None:
+                    var["value"] = ""
                 name = var["key"]
                 config["variables"][name] = var["value"]
 
@@ -216,7 +219,10 @@ def run(runner, job, docker):
             success = True
         except errors.GitlabEmulatorError:
             # the job failed
-            emulator_job.abort()
+            try:
+                emulator_job.abort()
+            except OSError:
+                pass
         except requests.HTTPError:
             error = True
             emulator_job.abort()
